@@ -149,7 +149,7 @@ def scan_file(filename: str) -> Generator[PotentialSecret, None, None]:
         has_secret = False
         for lines in _get_lines_from_file(filename):
             for secret in _process_line_based_plugins(
-                lines=list(enumerate(lines, 1)),
+                lines=list(enumerate(lines, start=1)),
                 filename=filename,
             ):
                 has_secret = True
@@ -197,7 +197,7 @@ def scan_for_allowlisted_secrets_in_file(filename: str) -> Generator[PotentialSe
     # know which lines we want to scan.
     try:
         for lines in _get_lines_from_file(filename):
-            yield from _scan_for_allowlisted_secrets_in_lines(enumerate(lines, 1), filename)
+            yield from _scan_for_allowlisted_secrets_in_lines(enumerate(lines, start=1), filename)
             break
     except IOError:
         log.warning(f'Unable to open file: {filename}')
