@@ -49,7 +49,7 @@ class BasePlugin(metaclass=ABCMeta):
         **kwargs: Any
     ) -> Set[PotentialSecret]:
         """This examines a line and finds all possible secret values in it."""
-        output = set([])
+        output = set()
         for match in self.analyze_string(line, **kwargs):   # type: ignore
             output.add(
                 PotentialSecret(
@@ -145,7 +145,12 @@ class RegexBasedDetector(BasePlugin, metaclass=ABCMeta):
     def analyze_string(self, string: str) -> Generator[str, None, None]:
         for regex in self.denylist:
             for match in regex.findall(string):
-                yield match
+                if isinstance(match, tuple):
+                    for submatch in filter(bool, match):
+                        # It might make sense to paste break after yielding
+                        yield submatch
+                else:
+                    yield match
 
     @staticmethod
     def build_assignment_regex(
